@@ -61,6 +61,9 @@ const char *vaProfileStr(VAProfile profile)
     TOSTR(VAProfileHEVCSccMain);
     TOSTR(VAProfileHEVCSccMain10);
     TOSTR(VAProfileHEVCSccMain444);
+    TOSTR(VAProfileAV1Profile0);
+    TOSTR(VAProfileAV1Profile1);
+    TOSTR(VAProfileHEVCSccMain444_10);
     default: break;
     }
     return "<unknown profile>";
@@ -124,6 +127,8 @@ const char *vaConfigAttribTypeStr(VAConfigAttribType configAttribType)
     TOSTR(VAConfigAttribQPBlockSize);
     TOSTR(VAConfigAttribStats);
     TOSTR(VAConfigAttribMaxFrameSize);
+    TOSTR(VAConfigAttribPredictionDirection);
+    TOSTR(VAConfigAttribMultipleFrame);
     case VAConfigAttribTypeMax: break;
     }
     return "<unknown config attribute type>";
