@@ -49,6 +49,10 @@ extern int va_trace_flag;
     if (va_trace_flag) {                        \
         trace_func(__VA_ARGS__);                \
     }
+#define VA_TRACE_RET(dpy,ret)                   \
+    if (va_trace_flag){                         \
+        va_TraceStatus(dpy, __func__, ret);     \
+    }
 
 DLL_HIDDEN
 void va_TraceInit(VADisplay dpy);
@@ -120,6 +124,34 @@ void va_TraceDestroyContext (
     VAContextID context
 );
 
+DLL_HIDDEN
+void va_TraceCreateMFContext (
+    VADisplay dpy,
+    VAContextID *mf_context	/* out */
+);
+
+DLL_HIDDEN
+void va_TraceMFAddContext (
+    VADisplay dpy,
+    VAMFContextID mf_context,
+    VAContextID context
+);
+
+DLL_HIDDEN
+void va_TraceMFReleaseContext (
+    VADisplay dpy,
+    VAMFContextID mf_context,
+    VAContextID context
+);
+
+DLL_HIDDEN
+void va_TraceMFSubmit (
+    VADisplay dpy,
+    VAMFContextID mf_context,
+    VAContextID *contexts,
+    int num_contexts
+);
+
 DLL_HIDDEN
 void va_TraceCreateBuffer (
     VADisplay dpy,
@@ -167,6 +199,13 @@ void va_TraceEndPicture(
     int endpic_done
 );
 
+DLL_HIDDEN
+void va_TraceEndPictureExt(
+    VADisplay dpy,
+    VAContextID context,
+    int endpic_done
+);
+
 DLL_HIDDEN
 void va_TraceSyncSurface(
     VADisplay dpy,
@@ -242,6 +281,8 @@ void va_TracePutSurface (
     unsigned int flags /* de-interlacing flags */
 );
 
+void va_TraceStatus(VADisplay dpy, const char * funcName, VAStatus status);
+
 #ifdef __cplusplus
 }
 #endif
